==> jc-1.4.0.tar.gz: java__5fcup/lexer.h <==
// public class java_cup.lexer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 93616ebe064ff58d java__5fcup_lexer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_lexer_H_
#define _JC_java__5fcup_lexer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java__5fcup_runtime_Symbol$object;

// Typedefs
typedef struct _jc_java__5fcup_lexer$sub_refs	_jc_java__5fcup_lexer$sub_refs;
typedef struct _jc_java__5fcup_lexer$sub_nonrefs	_jc_java__5fcup_lexer$sub_nonrefs;
typedef struct _jc_java__5fcup_lexer$refs	_jc_java__5fcup_lexer$refs;
typedef struct _jc_java__5fcup_lexer$nonrefs	_jc_java__5fcup_lexer$nonrefs;
typedef struct _jc_java__5fcup_lexer$object	_jc_java__5fcup_lexer$object;

typedef struct _jc_java__5fcup_lexer$fields_struct	_jc_java__5fcup_lexer$fields_struct;
typedef const struct _jc_java__5fcup_lexer$vmethods	_jc_java__5fcup_lexer$vmethods;
typedef const struct _jc_java__5fcup_lexer$vtable	_jc_java__5fcup_lexer$vtable;
typedef const struct _jc_java__5fcup_lexer$vtype	_jc_java__5fcup_lexer$vtype;

// Class fields structure
struct _jc_java__5fcup_lexer$fields_struct {
	struct _jc_java_util_Hashtable$object	*char__5fsymbols;
	struct _jc_java_util_Hashtable$object	*keywords;
	jint	EOF__5fCHAR;
	jint	absolute__5fposition;
	jint	current__5fline;
	jint	current__5fposition;
	jint	error__5fcount;
	jint	next__5fchar;
	jint	next__5fchar2;
	jint	next__5fchar3;
	jint	next__5fchar4;
	jint	warning__5fcount;
};
extern _jc_java__5fcup_lexer$fields_struct _jc_java__5fcup_lexer$class_fields;

// Constructors
extern void _jc_java__5fcup_lexer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_lexer$object *);

// Static methods
extern void _jc_java__5fcup_lexer$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_java__5fcup_lexer$method$advance$3cb6335d931ec4c0(_jc_env *);
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_java__5fcup_lexer$method$debug__5fnext__5ftoken$5389922efa2d6398(_jc_env *);
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_java__5fcup_lexer$method$do__5fcode__5fstring$62d6063b54870214(_jc_env *);
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_java__5fcup_lexer$method$do__5fid$8dd3eab0e6714b43(_jc_env *);
extern void _jc_java__5fcup_lexer$method$emit__5ferror$81487a8000d8a34f(_jc_env *, struct _jc_java_lang_String$object *);
extern void _jc_java__5fcup_lexer$method$emit__5fwarn$6a72df01686bc1c8(_jc_env *, struct _jc_java_lang_String$object *);
extern jint _jc_java__5fcup_lexer$method$find__5fsingle__5fchar$cd809f13a05c9a3a(_jc_env *, jint);
extern jboolean _jc_java__5fcup_lexer$method$id__5fchar$3b620388622a3b7f(_jc_env *, jint);
extern jboolean _jc_java__5fcup_lexer$method$id__5fstart__5fchar$78e75a93e0eecc78(_jc_env *, jint);
extern void _jc_java__5fcup_lexer$method$init$d82f2cc8ccf1c754(_jc_env *);
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_java__5fcup_lexer$method$next__5ftoken$d2d2cf57fe6820fc(_jc_env *);
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_java__5fcup_lexer$method$real__5fnext__5ftoken$38030efbf46c0a3a(_jc_env *);
extern void _jc_java__5fcup_lexer$method$swallow__5fcomment$08acce42364b41df(_jc_env *);

// Virtual methods structure
struct _jc_java__5fcup_lexer$vmethods {
};

// Vtable
struct _jc_java__5fcup_lexer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_lexer$vmethods	java__5fcup_lexer;
};

// Vtype
struct _jc_java__5fcup_lexer$vtype {
	_jc_type			type;
	_jc_java__5fcup_lexer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_lexer$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_lexer$refs {
    _jc_java__5fcup_lexer$sub_refs	java__5fcup_lexer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_lexer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_lexer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_lexer$sub_nonrefs	java__5fcup_lexer;
};

// Object instance structure
struct _jc_java__5fcup_lexer$object {
	_jc_java__5fcup_lexer$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_lexer$vtype	*vtype;
	_jc_java__5fcup_lexer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_lexer$vtype _jc_java__5fcup_lexer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_lexer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_lexer$class_object;

#endif	/* _JC_java__5fcup_lexer_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/lexer.h <==
// public class java_cup.lexer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 93616ebe064ff58d java__5fcup_lexer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_lexer_H_
#define _JC_java__5fcup_lexer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java__5fcup_runtime_Symbol$object;

// Typedefs
typedef struct _jc_java__5fcup_lexer$sub_refs	_jc_java__5fcup_lexer$sub_refs;
typedef struct _jc_java__5fcup_lexer$sub_nonrefs	_jc_java__5fcup_lexer$sub_nonrefs;
typedef struct _jc_java__5fcup_lexer$refs	_jc_java__5fcup_lexer$refs;
typedef struct _jc_java__5fcup_lexer$nonrefs	_jc_java__5fcup_lexer$nonrefs;
typedef struct _jc_java__5fcup_lexer$object	_jc_java__5fcup_lexer$object;

typedef struct _jc_java__5fcup_lexer$fields_struct	_jc_java__5fcup_lexer$fields_struct;
typedef const struct _jc_java__5fcup_lexer$vmethods	_jc_java__5fcup_lexer$vmethods;
typedef const struct _jc_java__5fcup_lexer$vtable	_jc_java__5fcup_lexer$vtable;
typedef const struct _jc_java__5fcup_lexer$vtype	_jc_java__5fcup_lexer$vtype;

// Class fields structure
struct _jc_java__5fcup_lexer$fields_struct {
	struct _jc_java_util_Hashtable$object	*char__5fsymbols;
	struct _jc_java_util_Hashtable$object	*keywords;
	jint	EOF__5fCHAR;
	jint	absolute__5fposition;
	jint	current__5fline;
	jint	current__5fposition;
	jint	error__5fcount;
	jint	next__5fchar;
	jint	next__5fchar2;
	jint	next__5fchar3;
	jint	next__5fchar4;
	jint	warning__5fcount;
};
extern _jc_java__5fcup_lexer$fields_struct _jc_java__5fcup_lexer$class_fields;

// Constructors
extern void _jc_java__5fcup_lexer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_lexer$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java__5fcup_lexer$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_lexer$method$advance$3cb6335d931ec4c0(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_java__5fcup_lexer$method$debug__5fnext__5ftoken$5389922efa2d6398(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_java__5fcup_lexer$method$do__5fcode__5fstring$62d6063b54870214(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_java__5fcup_lexer$method$do__5fid$8dd3eab0e6714b43(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_lexer$method$emit__5ferror$81487a8000d8a34f(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_lexer$method$emit__5fwarn$6a72df01686bc1c8(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jint _jc_java__5fcup_lexer$method$find__5fsingle__5fchar$cd809f13a05c9a3a(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java__5fcup_lexer$method$id__5fchar$3b620388622a3b7f(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java__5fcup_lexer$method$id__5fstart__5fchar$78e75a93e0eecc78(_jc_env *, jint) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_lexer$method$init$d82f2cc8ccf1c754(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_java__5fcup_lexer$method$next__5ftoken$d2d2cf57fe6820fc(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_java__5fcup_lexer$method$real__5fnext__5ftoken$38030efbf46c0a3a(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_lexer$method$swallow__5fcomment$08acce42364b41df(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java__5fcup_lexer$vmethods {
};

// Vtable
struct _jc_java__5fcup_lexer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_lexer$vmethods	java__5fcup_lexer;
};

// Vtype
struct _jc_java__5fcup_lexer$vtype {
	_jc_type			type;
	_jc_java__5fcup_lexer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_lexer$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_lexer$refs {
    _jc_java__5fcup_lexer$sub_refs	java__5fcup_lexer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_lexer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_lexer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_lexer$sub_nonrefs	java__5fcup_lexer;
};

// Object instance structure
struct _jc_java__5fcup_lexer$object {
	_jc_java__5fcup_lexer$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_lexer$vtype	*vtype;
	_jc_java__5fcup_lexer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_lexer$vtype _jc_java__5fcup_lexer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_lexer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_lexer$class_object;

#endif	/* _JC_java__5fcup_lexer_H_ */
